# 2022-11-22 - Composable Stable Pool V2

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This deployment was deprecated in favor of a new version with critical fixes: [composable-stable-pool-v3](../20230206-composable-stable-pool-v3/).
> See this [forum post](https://forum.balancer.fi/t/reentrancy-vulnerability-scope-expanded/4345) for more details about the fixed vulnerability.

Redeployment of `ComposableStablePoolFactory`, which allows creating Stable Pools that are suitable to be included in other Pools. This version adds proportional joins and exits, to improve the front-end UX.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`ComposableStablePoolFactory` artifact](./artifact/ComposableStablePoolFactory.json)
